@@ -105,7 +105,7 @@ class Package(SirenComponent):
             params={'page_size': count}
         )
 
-        return self.DatasetFactory._from_v2_list_response(response.json())
+        return self._DatasetFactory._from_v2_list_response(response.json())
 
 
     def register_package(
@@ -208,7 +208,7 @@ class Package(SirenComponent):
         warnings.warn(
             "Deprecation Warning: registering a package (and other CRUD package operations) using SDK "
             "register_package will be deprecated in near future (by November 2020). The API should be used "
-            "instead, fill details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
+            "instead, find details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
             PendingDeprecationWarning
         )
 
@@ -359,7 +359,7 @@ class Package(SirenComponent):
         warnings.warn(
             "Deprecation Warning: editing a package (and other CRUD package operations) using SDK "
             "edit_package will be deprecated in near future (by November 2020). The API should be used "
-            "instead, fill details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
+            "instead, find details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
             PendingDeprecationWarning
         )
         fields = filter_out_unknown_keys(to_camel_cased_dict(kwargs),
@@ -411,7 +411,7 @@ class Package(SirenComponent):
         warnings.warn(
             "Deprecation Warning: deleting a package (and other CRUD package operations) using SDK "
             "delete_package will be deprecated in near future (by November 2020). The API should be used "
-            "instead, fill details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
+            "instead, find details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
             PendingDeprecationWarning
         )
         self.session.delete(
