@@ -9,11 +9,14 @@ import logging
 import textwrap
 import uuid
 import warnings
-from typing import List, Optional
+from functools import partial
+from typing import List, Optional, Tuple, Union
 from urllib.parse import urljoin
 
 import pandas
 import pyarrow
+
+from dli.aws import match_partitions, filter_by_load_type_full
 from dli.client.aspects import analytics_decorator, logging_decorator
 from dli.client.components.urls import consumption_urls, dataset_urls
 from dli.client.exceptions import DataframeStreamingException
@@ -34,6 +37,55 @@ class StructuredDatasetModel(DatasetModel):
         self.instances = self._client._InstancesCollection(dataset=self)
         self.fields_metadata = None
 
+    def __repr__(self):
+        return f'<Structured Dataset short_code={self.short_code}>'
+
+    def __str__(self):
+        separator = "-" * 80
+        splits = "\n".join(textwrap.wrap(self.description))
+
+        return f"\nDATASET \"{self.short_code}\" [{self.data_format}]\n" \
+               f">> Shortcode: {self.short_code}\n"\
+               f">> Available Date Range: {self.first_datafile_at} to {self.last_datafile_at}\n" \
+               f">> ID: {self.id}\n" \
+               f">> Published: {self.publishing_frequency} by {self.organisation_name}\n" \
+               f">> Accessible: {self.has_access}\n" \
+               f"\n" \
+               f"{splits}\n" \
+               f"{separator}"
+
+    def __custom_filter(
+        self,
+        partitions: List[str],
+        paths: List[Tuple[str, int]],
+    ) -> List[Tuple[str, int]]:
+        """
+        Filters that apply to Structured datasets
+        """
+
+        # For a Structured dataset, we expect the first common prefix on S3
+        # to be an `as_of` representing when the data was published.
+        #
+        # If the dataset's load type is "Full Load"
+        # then return only data from the most recent `as_of` common prefix.
+        # Else (if the dataset's load type is "Incremental Load" or None),
+        # then we return data from all as_of common prefixes.
+        paths: List[Tuple[str, int]] = \
+            filter_by_load_type_full(paths, self.load_type)
+
+        trace_logger.info(
+            f"Number of paths on S3 for this dataset "
+            f"after filtering for load type: '{len(paths)}'"
+        )
+
+        if partitions:
+            # Only return paths that match the partition(s) provided.
+            paths = [
+                path for path in paths if match_partitions(path[0], partitions)
+            ]
+
+        return paths
+
     @property
     def sample_data(self) -> SampleData:
         return SampleData(self)
@@ -41,7 +93,7 @@ class StructuredDatasetModel(DatasetModel):
     def dask_dataframe(
         self,
         # Parameters for reading from .parquet and .csv format files:
-        partitions: Optional[List[str]] = None,
+        partitions: Optional[Union[str, List[str]]] = None,
         # Parameters for reading from .parquet format files:
         columns=None,
         filters=None,
@@ -420,10 +472,381 @@ class StructuredDatasetModel(DatasetModel):
             )
             return None
 
+    def partitions(self) -> dict:
+        """
+        Retrieves the list of available partitions for a given dataset.
+
+        The data onboarding team have structured the file paths on S3 with
+        simple partitions e.g. `as_of_date` or `location`.
+
+        Their aim was to separate the data to reduce the size of the
+        individual files. For example, data that has a `location` column with
+        the options `us`, `eu` and `asia` can be separated into S3 paths like
+        so:
+
+        .. code-block::
+
+            package-name/dataset/as_of_date=2019-09-10/location=eu/filename.csv
+            package-name/dataset/as_of_date=2019-09-10/location=us/filename.csv
+
+        in this case the `partitions` will be returned as:
+
+        .. code-block::
+
+            {'as_of_date': ['2019-09-10'], 'location': ['eu', 'us]}
+        """
+        response = self._client.session.get(
+            urljoin(
+                self._client._environment.consumption,
+                consumption_urls.consumption_partitions.format(id=self.id)
+            )
+        )
+
+        return response.json()["data"]["attributes"]["partitions"]
+
+    def list(
+        self,
+        request_id=None,
+        partitions: Optional[Union[str, List[str]]] = None,
+        filter_path: Optional[str] = None,
+        absolute_path: bool = True,
+        skip_hidden_files: bool = True,
+    ) -> List[str]:
+        """
+        List all the paths to files in the dataset. Calls go via the
+        Datalake's S3 proxy, so the returned paths will be returned in the
+        style of the S3 proxy, so in the pattern
+        `s3://organisation_short_code/dataset_short_code/<path>`.
+        S3 proxy does not return direct paths to the real location on S3 as
+        they may be sensitive.
+
+        The list will filter out paths where:
+        * The size is zero bytes.
+        * The name of any partition within the path is prefixed with a `.` or
+        a `_` as that means it is intended as a hidden file.
+        * The name of any partition within the path is exactly the word
+        `metadata`.
+        * It is a directory rather than a file.
+        * Files with the wrong extension for the dataset's type i.e for
+        a .parquet dataset we will return only .parquet files, zero .csv
+        files.
+
+        This list will filter based on `load_type` of the dataset. When the
+        dataset's `load_type` is `Incremental Load` then files will be listed
+        from all of the `as_of_date` partitions on S3. When the
+        dataset's `load_type` is `Full Load` then files will be listed only
+        the most recent `as_of_date` partition on S3.
+        Please see the support library documentation for more information
+        about how the `load type` affects the data you can access in a dataset:
+        https://supportlibrary.ihsmarkit.com/display/DLSL/Exploring+Datasets#ExploringDatasets-Howthe%60loadtype%60affectsthedatayoucanaccessinadataset
+
+        Parameters
+        ----------
+        :param str request_id: Optional. Automatically generated value
+            used by our logs to correlate a user journey across several
+            requests and across multiple services.
+
+        :param List[str] partitions: Optional. A list of filters (partitions)
+            to apply to the file paths on S3.
+
+            This allows the user to filter the files they want to read from
+            before they  have to read any data. This will reduce the amount
+            of redundant data that is transferred over the network and
+            reduce the amount of memory required on the user's machine.
+
+            For any dataset, the paths on S3 may contain
+            partitions that are key-value pairs in the format
+            `<key>=<value>`, for example in the path:
+
+                s3://example/as_of_date=2020-01-01/country=US/file.extension
+
+            there are the partitions:
+
+            * `country=US`
+            * `as_of_date=2020-01-01`.
+
+            You can find the available list of partitions for a dataset by
+            calling the dataset's `.partitions()` endpoint.
+
+            You can specify a list partitions you want to get data from by
+            passing in a list in the format `<key><operator><value>`. Please
+            note that you should not include any extra quotation marks around
+            the value, so `as_of_date=2020-01-01` is valid but
+            `as_of_date='2020-01-01'` is invalid.
+
+            The supported operators are: `<=`, `<`, `=`, `>`, `>=` and
+            `!=`.
+
+            For a partition where the key is named `as_of_date`, the value
+            is treated as a Python datetime object, so comparisons are done
+            between dates. This means that the `>=` and `<=` operators can
+            be used to get data in a date range where more than one
+            `as_of_date` exists. For example, to get data from only dates in
+            January 2020:
+
+            .. code-block:: python
+
+                dataset.list(partitions=[
+                    'as_of_date>=2020-01-01',
+                    'as_of_date<=2020-01-31',
+                ])
+
+            Other key names will have their values treated as string, so the
+            operators will perform Python string comparisons.
+
+            .. code-block:: python
+
+                dataset.list(partitions=[
+                    'country=US'
+                ])
+
+            A list of partitions is applied as a logical AND. So specifying
+            `as_of_date` and `country` will match only those paths that
+            match both `as_of_date` AND `country`.
+
+            .. code-block:: python
+
+                dataset.list(partitions=[
+                    'as_of_date>=2020-01-01',
+                    'country=US',
+                ])
+
+        :param str filter_path: Optional. If provided only a subpath matching
+            the filter_path will be matched. This is less flexible than using
+            the `partitions` parameter, so we recommend you pass in
+            `partitions` instead. The `partitions` can deal with the
+            partitions in the path being in any order, but filter_path relies
+            on a fixed order of partitions that the user needs to know ahead
+            of time.
+
+            Example usage to get all paths that start with the `as_of_date`
+            2020. Note this is a string comparison, not a datetime comparison.
+
+            .. code-block:: python
+
+                dataset.list(filter_path='as_of_date=2020')
+
+        :param bool absolute_path: True (default) for returning an
+            absolute path to the path on the S3 proxy. False to return a
+            relative path (this is useful if using a TransferManager).
+
+        :param bool skip_hidden_files: True (default) skips files that have
+            been uploaded to S3 by Spark jobs. These usually start with a
+            `.` or `_`.
+        """
+
+        if filter_path and partitions:
+            raise ValueError(
+                'Both `partitions` and `filter_path` are set. Please only '
+                'provide one of these parameters.'
+            )
+
+        if filter_path is not None:
+            warnings.warn(
+                'Parameter `filter_path` will be deprecated in a future '
+                'release, please use `partitions` instead.',
+                PendingDeprecationWarning
+            )
+
+        if type(partitions) == str:
+            partitions = [partitions]
+
+        return self._DatasetModel__list(
+            request_id=request_id,
+            custom_filter_func=partial(self.__custom_filter, partitions=partitions),
+            filter_path=filter_path,
+            absolute_path=absolute_path,
+            skip_hidden_files=skip_hidden_files
+        )
+
+    def download(
+        self,
+        destination_path: str,
+        flatten: Optional[bool] = False,
+        filter_path: Optional[str] = None,
+        partitions: Optional[Union[str, List[str]]] = None,
+    ) -> List[str]:
+        """
+        Downloads the original dataset files from the data lake to local copy
+        destination of your choice.
+
+        The flatten parameter retains only the file name, and places the
+        files in the directory specified, else the files will be downloaded
+        matching the directory structure as housed on the data lake.
+
+        The filter path and partitions parameters specify that only a subset
+        of the S3 path should be downloaded.
+
+        Parameters
+        ----------
+        :param destination_path: required. The path on the system, where the
+            files should be saved. Must be a directory, if doesn't exist, will
+            be created.
+
+        :param bool flatten: The flatten parameter default behaviour
+            (flatten=False) will allow the user to specify that they would
+            like to keep the underlying folder structure when writing the
+            downloaded files to disk.
+            When “flatten” is set to True the
+            folder structure and download all data to the specified path in
+            and retains only the original file name. This is not useful if the
+            file names are identical for multiple files.
+
+        :param str filter_path: Optional. If provided only a subpath matching
+            the filter_path will be matched. This is less flexible than using
+            the `partitions` parameter, so we recommend you pass in
+            `partitions` instead. The `partitions` can deal with the
+            partitions in the path being in any order, but filter_path relies
+            on a fixed order of partitions that the user needs to know ahead
+            of time.
+
+            Example usage to get all paths that start with the `as_of_date`
+            2020. Note this is a string comparison, not a datetime comparison.
+
+            .. code-block:: python
+
+                dataset.download(filter_path='as_of_date=2020')
+
+        :param List[str] partitions: Optional. A list of filters (partitions)
+            to apply to the file paths on S3.
+
+            This allows the user to filter the files they want to read from
+            before they  have to read any data. This will reduce the amount
+            of redundant data that is transferred over the network and
+            reduce the amount of memory required on the user's machine.
+
+            For any dataset, the paths on S3 may contain
+            partitions that are key-value pairs in the format
+            `<key>=<value>`, for example in the path:
+
+                s3://example/as_of_date=2020-01-01/country=US/file.extension
+
+            there are the partitions:
+
+            * `country=US`
+            * `as_of_date=2020-01-01`.
+
+            You can find the available list of partitions for a dataset by
+            calling the dataset's `.partitions()` endpoint.
+
+            You can specify a list of partitions you want to get data from by
+            passing in a list in the format `<key><operator><value>`. Please
+            note that you should not include any extra quotation marks around
+            the value, so `as_of_date=2020-01-01` is valid but
+            `as_of_date='2020-01-01'` is invalid.
+
+            The supported operators are: `<=`, `<`, `=`, `>`, `>=` and
+            `!=`.
+
+            For a partition where the key is named `as_of_date`, the value
+            is treated as a Python datetime object, so comparisons are done
+            between dates. This means that the `>=` and `<=` operators can
+            be used to get data in a date range where more than one
+            `as_of_date` exists. For example, to get data from only dates in
+            January 2020:
+
+            .. code-block:: python
+
+                dataset.download(partitions=[
+                    'as_of_date>=2020-01-01',
+                    'as_of_date<=2020-01-31',
+                ])
+
+            Other key names will have their values treated as string, so the
+            operators will perform Python string comparisons.
+
+            .. code-block:: python
+
+                dataset.download(partitions=[
+                    'country=US'
+                ])
+
+            A list of partitions is applied as a logical AND. So specifying
+            `as_of_date` and `country` will match only those paths that
+            match both `as_of_date` AND `country`.
+
+            .. code-block:: python
+
+                dataset.download(partitions=[
+                    'as_of_date>=2020-01-01',
+                    'country=US',
+                ])
+
+        :return: the list of the files that were downloaded successfully. Any
+            failures will be printed.
+
+
+        :example:
+
+            Downloading without flatten:
+
+            .. code-block:: python
+
+                dataset.download('./local/path/')
+
+                [
+                  'as_of_date=2019-09-10/type=full/StormEvents_details-ftp_v1.0_d1950_c20170120.csv.gz',
+                  'as_of_date=2019-09-11/type=full/StormEvents_details-ftp_v1.0_d1951_c20160223.csv.gz'
+                ]
+
+        :example:
+
+            Downloading with ``filter_path``
+
+            .. code-block:: python
+
+                dataset.download(
+                    './local/path/', filter_path='as_of_date=2019-09-10/'
+                )
+                [
+                  'as_of_date=2019-09-10/type=full/StormEvents_details-ftp_v1.0_d1950_c20170120.csv.gz',
+                ]
+
+
+        :example:
+
+            When flatten = True, we remove the s3 structure. Example:
+
+            Example output for new behaviour:
+
+            .. code-block:: python
+
+                dataset.download('./local/path/', flatten=True)
+                [
+                  'StormEvents_details-ftp_v1.0_d1950_c20170120.csv.gz',
+                  'StormEvents_details-ftp_v1.0_d1951_c20160223.csv.gz'
+                ]
+
+
+        """
+
+        if filter_path and partitions:
+            raise ValueError(
+                'Both `partitions` and `filter_path` are set. Please only '
+                'provide one of these parameters.'
+            )
+
+        if filter_path is not None:
+            warnings.warn(
+                'Parameter `filter_path` will be deprecated in a future release, please use `partitions` instead.',
+                PendingDeprecationWarning
+            )
+
+        if type(partitions) == str:
+            partitions = [partitions]
+
+        return self._DatasetModel__download(
+            destination_path=destination_path,
+            flatten=flatten,
+            filter_path=filter_path,
+            custom_filter_func=partial(self.__custom_filter, partitions=partitions),
+            skip_hidden_files=True
+        )
+
     def dataframe(
         self,
         nrows: Optional[int] = None,
-        partitions: Optional[List[str]] = None,
+        partitions: Optional[Union[str, List[str]]] = None,
         raise_: bool = True,
         use_compression: bool = False
     ) -> pandas.DataFrame:
@@ -547,6 +970,9 @@ class StructuredDatasetModel(DatasetModel):
             params['filter[nrows]'] = nrows
 
         if partitions is not None:
+            if type(partitions) == str:
+                partitions = [partitions]
+
             params['filter[partitions]'] = partitions
 
         dataframe_url = urljoin(
@@ -722,23 +1148,6 @@ class StructuredDatasetModel(DatasetModel):
         else:
             print("No columns/info available.")
 
-    def __repr__(self):
-        return f'<Structured Dataset short_code={self.short_code}>'
-
-    def __str__(self):
-        separator = "-" * 80
-        splits = "\n".join(textwrap.wrap(self.description))
-
-        return f"\nDATASET \"{self.short_code}\" [{self.data_format}]\n" \
-               f">> Shortcode: {self.short_code}\n"\
-               f">> Available Date Range: {self.first_datafile_at} to {self.last_datafile_at}\n" \
-               f">> ID: {self.id}\n" \
-               f">> Published: {self.publishing_frequency} by {self.organisation_name}\n" \
-               f">> Accessible: {self.has_access}\n" \
-               f"\n" \
-               f"{splits}\n" \
-               f"{separator}"
-
 
 log_public_functions_calls_using(
     [analytics_decorator, logging_decorator],
