@@ -5,7 +5,7 @@
 import os
 from collections import OrderedDict
 from typing import Dict
-
+from functools import partial
 import requests
 
 from dli.client.exceptions import CatalogueEntityNotFoundException
@@ -17,7 +17,7 @@ from dli.modules.package_module import PackageModule
 
 class DatasetModule:
 
-    def __call__(self, search_term=None, only_mine=False) \
+    def __call__(self, search_term=None, only_mine=False, warn=False) \
             -> Dict[str, DatasetModel]:
         """
         See datasets.
@@ -110,8 +110,8 @@ class DatasetModule:
 
         p = Paginator(
             dataset_urls.v2_index,
-            self._client.DatasetFactory,
-            self._client.DatasetFactory._from_v2_response_unsheathed,
+            self._client._DatasetFactory,
+            partial(self._client._DatasetFactory._from_v2_response_unsheathed, warn=warn),
             page_size=5000,
             max_workers=5,
             filters=filters
@@ -159,7 +159,8 @@ class DatasetModule:
         )
 
         # todo - not going to work as expected since the orderdict wont have dups
-        res = self._client.datasets(search_term=search_terms, only_mine=False).get(short_code)
+        res = self._client.datasets(search_term=search_terms, only_mine=False, warn=True)
+        res = res.get(short_code)
 
         if type(res) is list:
             if os.name != 'nt':
