@@ -100,7 +100,7 @@ class SdkIntegrationTestCase(unittest.TestCase):
             "manager_id":  "datalake-mgmt",
             "access_manager_id":  "datalake-mgmt",
             "tech_data_ops_id":  "datalake-mgmt",
-            "topic":  "Academic/Education",
+            "topic":  "Climate",
             "access":  access,
             "internal_data":  "No",
             "data_sensitivity":  "Public",
@@ -120,7 +120,7 @@ class SdkIntegrationTestCase(unittest.TestCase):
             package_id=package_id,
             name=dataset_name,
             description='a testing dataset',
-            content_type='Pricing',
+            content_type='Structured',
             data_format='CSV',
             publishing_frequency='Daily',
             taxonomy=[],
@@ -160,7 +160,7 @@ class SdkIntegrationTestCase(unittest.TestCase):
 
 
     def create_session(self):
-        return session.start_session(self.api_key, self.root_url)
+        return session._start_session(self.api_key, self.root_url)
 
     def register_aws_account(self, aws_account_id):
         response = requests.post(
