@@ -36,7 +36,7 @@ class DatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             data_as_of='2000-01-01'
         )
-        
+
         return datafile
 
     def test_get_unknown_datafile_raises_exception(self):
@@ -56,7 +56,7 @@ class DatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             data_as_of='2000-01-01'
         )
-        
+
 
         s3_datafile = self.client.get_s3_datafile(datafile.datafile_id)
         self.assertEqual(s3_datafile.datafile_id, datafile.datafile_id)
@@ -111,23 +111,25 @@ class DatafileTestCase(SdkIntegrationTestCase):
             self.client.edit_datafile_metadata("unknown")
 
     def test_register_s3_datafile_can_create_datafile_uploading_files(self):
-        dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
-        file = os.path.relpath(__file__)  # upload ourselves as a dataset
-        datafile = self.client.register_s3_datafile(
-            dataset.dataset_id,
-            "test_register_s3_datafile_can_create_datafile_uploading_files",
-            [file],
-            "prefix",
-            data_as_of='2000-01-01'
-        )
-        
+        with patch('dli.client.s3.Client.upload_files_to_s3',
+                   self.patch_upload_files_to_s3) as s3_upload:
+            dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
+            file = os.path.relpath(__file__)  # upload ourselves as a dataset
+            datafile = self.client.register_s3_datafile(
+                dataset.dataset_id,
+                "test_register_s3_datafile_can_create_datafile_uploading_files",
+                [file],
+                "prefix",
+                data_as_of='2000-01-01'
+            )
 
-        self.assertIsNotNone(datafile)
-        self.assertEqual(datafile.dataset_id, dataset.dataset_id)
-        self.assertEqual(datafile.files, [
-            {"path": "s3://dev-ihsm-dl-pkg-test/prefix/" +
-                os.path.basename(file)}
-        ])
+
+            self.assertIsNotNone(datafile)
+            self.assertEqual(datafile.dataset_id, dataset.dataset_id)
+            self.assertEqual(datafile.files, [
+                {"path": "s3://dev-ihsm-dl-pkg-test/prefix/" +
+                    os.path.basename(file)}
+            ])
 
     def test_register_datafile_metadata_on_datalake_dataset(self):
         dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
@@ -178,33 +180,35 @@ class DatafileTestCase(SdkIntegrationTestCase):
             self.client.delete_datafile("unknown")
 
     def test_can_add_files_to_existing_datafile(self):
-        file = os.path.relpath(__file__)  # upload ourselves as a dataset
-        file2 = '../test_sandbox/samples/data/AAPL.csv'
+        with patch('dli.client.s3.Client.upload_files_to_s3',
+                   self.patch_upload_files_to_s3) as s3_upload:
+            file = os.path.relpath(__file__)  # upload ourselves as a dataset
+            file2 = '../test_sandbox/samples/data/AAPL.csv'
 
-        dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
-        datafile = self.client.register_s3_datafile(
-            dataset.dataset_id,
-            "test_can_add_files_to_existing_datafile",
-            [file],
-            "prefix",
-            data_as_of='2000-01-01'
-        )
-        
+            dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
+            datafile = self.client.register_s3_datafile(
+                dataset.dataset_id,
+                "test_can_add_files_to_existing_datafile",
+                [file],
+                "prefix",
+                data_as_of='2000-01-01'
+            )
 
-        updated = self.client.add_files_to_datafile(
-            datafile.datafile_id, 'prefix', [file2])
 
-        # countEqual asserts that the collections match disrespect of order
-        # talk about naming stuff
-        self.assertCountEqual(
-            [
-                {"path": "s3://dev-ihsm-dl-pkg-test/prefix/" +
-                    os.path.basename(file)},
-                {"path": "s3://dev-ihsm-dl-pkg-test/prefix/" +
-                    os.path.basename(file2)}
-            ],
-            updated.files
-        )
+            updated = self.client.add_files_to_datafile(
+                datafile.datafile_id, 'prefix', [file2])
+
+            # countEqual asserts that the collections match disrespect of order
+            # talk about naming stuff
+            self.assertCountEqual(
+                [
+                    {"path": "s3://dev-ihsm-dl-pkg-test/prefix/" +
+                        os.path.basename(file)},
+                    {"path": "s3://dev-ihsm-dl-pkg-test/prefix/" +
+                        os.path.basename(file2)}
+                ],
+                updated.files
+            )
 
     def test_add_files_to_unknown_datafile_raises_exception(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
@@ -242,71 +246,75 @@ class DownloadDatafileTestCase(SdkIntegrationTestCase):
             self.client.download_datafile("unknown")
 
     def test_download_datafile_retrieves_all_files_in_datafile(self):
-        dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
-        datafile = self.client.register_s3_datafile(
-            dataset.dataset_id,
-            "test_download_dataset_retrieves_all_files_in_dataset",
-            [
-                '../test_sandbox/samples/data/AAPL.csv',
-                '../test_sandbox/samples/data/MSFT.csv'
-            ],
-            "prefix",
-            '2000-01-01'
-        )
-        
-        with patch('dli.client.s3.Client.download_files_from_s3_path') \
-                as s3_download:
-            with tempfile.TemporaryDirectory() as dest:
-                self.client.download_datafile(
-                    datafile.datafile_id,
-                    dest,
-                    flatten=False
-                )
+        with patch('dli.client.s3.Client.upload_files_to_s3',
+                   self.patch_upload_files_to_s3) as s3_upload:
+            dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
+            datafile = self.client.register_s3_datafile(
+                dataset.dataset_id,
+                "test_download_dataset_retrieves_all_files_in_dataset",
+                [
+                    '../test_sandbox/samples/data/AAPL.csv',
+                    '../test_sandbox/samples/data/MSFT.csv'
+                ],
+                "prefix",
+                '2000-01-01'
+            )
 
-                # validate we got the expected calls
-                s3_download.assert_has_calls([
-                    call(
-                        destination=dest,
-                        flatten=False,
-                        s3_path="s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv",
-                    ),
-                    call(
-                        destination=dest,
-                        flatten=False,
-                        s3_path = "s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv",
-                    ),
-                ], any_order=True)
-
-    def test_download_dataset_keeps_going_if_a_file_in_the_dataset_fails(self):
-        def _download(_, file, dest):
-            if file.endswith("AAPL.csv"):
-                raise Exception("")
-
-        dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
-        datafile = self.client.register_s3_datafile(
-            dataset.dataset_id,
-            "test_download_dataset_keeps_going_if_a_file_in_the_dataset_fails",
-            [
-                '../test_sandbox/samples/data/AAPL.csv',
-                '../test_sandbox/samples/data/MSFT.csv'
-            ],
-            "prefix",
-            '2000-01-01'
-        )
-        
-
-        with self.assertRaises(DownloadFailed):
-            with patch('dli.client.s3.Client.download_files_from_s3_path', _download) as s3_download:
+            with patch('dli.client.s3.Client.download_files_from_s3_path') \
+                    as s3_download:
                 with tempfile.TemporaryDirectory() as dest:
-                    self.client.download_datafile(datafile.datafile_id, dest)
+                    self.client.download_datafile(
+                        datafile.datafile_id,
+                        dest,
+                        flatten=False
+                    )
 
                     # validate we got the expected calls
                     s3_download.assert_has_calls([
-                        call("s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv", dest),
-                        call("s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv", dest),
-                    ],
-                        any_order=True
-                    )
+                        call(
+                            destination=dest,
+                            flatten=False,
+                            s3_path="s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv",
+                        ),
+                        call(
+                            destination=dest,
+                            flatten=False,
+                            s3_path = "s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv",
+                        ),
+                    ], any_order=True)
+
+    def test_download_dataset_keeps_going_if_a_file_in_the_dataset_fails(self):
+        with patch('dli.client.s3.Client.upload_files_to_s3',
+                   self.patch_upload_files_to_s3) as s3_upload:
+            def _download(_, file, dest):
+                if file.endswith("AAPL.csv"):
+                    raise Exception("")
+
+            dataset = self.create_s3_dataset("dev-ihsm-dl-pkg-test")
+            datafile = self.client.register_s3_datafile(
+                dataset.dataset_id,
+                "test_download_dataset_keeps_going_if_a_file_in_the_dataset_fails",
+                [
+                    '../test_sandbox/samples/data/AAPL.csv',
+                    '../test_sandbox/samples/data/MSFT.csv'
+                ],
+                "prefix",
+                '2000-01-01'
+            )
+
+
+            with self.assertRaises(DownloadFailed):
+                with patch('dli.client.s3.Client.download_files_from_s3_path', _download) as s3_download:
+                    with tempfile.TemporaryDirectory() as dest:
+                        self.client.download_datafile(datafile.datafile_id, dest)
+
+                        # validate we got the expected calls
+                        s3_download.assert_has_calls([
+                            call("s3://dev-ihsm-dl-pkg-test/prefix/MSFT.csv", dest),
+                            call("s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv", dest),
+                        ],
+                            any_order=True
+                        )
 
 
 @pytest.mark.integration
@@ -328,7 +336,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
     def test_can_upload_datafile_when_provided_folder_with_relative_path(self):
         sample_data = os.path.join(
             os.path.dirname(__file__),
-            'resources/yahoo'
+            '../../resources/yahoo'
         )
 
         datafile = self.client.register_s3_datafile(
@@ -338,7 +346,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
-        
+
 
         # assert the files were uploaded and that
         # their sizes have been resolved
@@ -358,7 +366,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
     def test_can_upload_datafile_when_provided_s3_prefix_without_trailing_slash(self):
         sample_data = os.path.join(
             os.path.dirname(__file__),
-            'resources/yahoo/AAPL.csv'
+            '../../resources/yahoo/AAPL.csv'
         )
 
         # Prefix Without trailing slash
@@ -369,7 +377,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
-        
+
 
         self.assertIn({
             "path": "s3://dev-ihsm-dl-pkg-test/prefix/AAPL.csv",
@@ -381,7 +389,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
     def test_can_upload_datafile_with_data_as_of_date_not_in_iso_format(self):
         sample_data = os.path.join(
             os.path.dirname(__file__),
-            'resources/yahoo/AAPL.csv'
+            '../../resources/yahoo/AAPL.csv'
         )
 
         datafile = self.client.register_s3_datafile(
@@ -391,7 +399,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '3210-1-1'
         )
-        
+
 
         assert self.client.get_datafile(datafile.datafile_id).data_as_of == '3210-01-01'
         assert {
@@ -402,7 +410,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
     def test_cannot_upload_datafile_with_invalid_data_as_of(self):
         sample_data = os.path.join(
             os.path.dirname(__file__),
-            'resources/yahoo/AAPL.csv'
+            '../../resources/yahoo/AAPL.csv'
         )
 
         with self.assertRaises(ValueError):
@@ -417,7 +425,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
     def test_can_upload_datafile_files_recursively(self):
         sample_data = os.path.join(
             os.path.dirname(__file__),
-            'resources/stocks'
+            '../../resources/stocks'
         )
 
         datafile = self.client.register_s3_datafile(
@@ -427,7 +435,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
             "prefix",
             '2000-01-01'
         )
-        
+
 
         # assert the files were uploaded and that
         # their sizes have been resolved
@@ -474,9 +482,8 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
              patch('dli.client.s3.os.makedirs') as makedirs_mock:
             sample_data = os.path.join(
                 os.path.dirname(__file__),
-                'resources/stocks'
+                '../../resources/stocks'
             )
-
             datafile = self.client.register_s3_datafile(
                 self.create_and_get_dataset_id(),
                 "test_download_datafile_should_keep_folder_structure_as_in_datafile",
@@ -484,31 +491,30 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 "prefix",
                 '2000-01-01'
             )
-            
 
             self.client.download_datafile(datafile.datafile_id, '/var/abc/')
 
             directories_created = [
-                d[0][0] for d in makedirs_mock.call_args_list
+                d[0][0] for d in makedirs_mock.call_args_list if
+                # Later version of boto I think create this automatically
+                '.aws' not in d[0][0]
             ]
 
             files_created = [
                 f[0][2] for f in download_file.call_args_list
             ]
 
-            assert directories_created == [
+            assert len(set(directories_created).intersection(set([
                 '/var/abc/prefix',
                 '/var/abc/prefix/microsoft',
-                '/var/abc/prefix/microsoft',
                 '/var/abc/prefix/microsoft/cortana'
-            ]
-
-            assert files_created == [
+            ]))) == len(set(directories_created))
+            assert len(set(files_created).intersection(set([
                 '/var/abc/prefix/readme.txt',
                 '/var/abc/prefix/microsoft/MSFT.csv',
                 '/var/abc/prefix/microsoft/AAPL.csv',
                 '/var/abc/prefix/microsoft/cortana/master.txt'
-            ]
+            ]))) == len(files_created)
 
     def test_download_datafile_returns_paths_where_files_were_downloaded(self):
         download_file = MagicMock()
@@ -528,7 +534,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 patch('dli.client.s3.os.makedirs') as makedirs_mock:
             sample_data = os.path.join(
                 os.path.dirname(__file__),
-                'resources/stocks'
+                '../../resources/stocks'
             )
 
             datafile = self.client.register_s3_datafile(
@@ -538,7 +544,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 "prefix",
                 '2000-01-01'
             )
-            
+
 
             returned_list_of_files = self.client.download_datafile(
                 datafile.datafile_id,'/var/abc/'
@@ -550,7 +556,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 '/var/abc/prefix/microsoft/AAPL.csv',
                 '/var/abc/prefix/microsoft/cortana/master.txt'
             ]
-            assert returned_list_of_files == files_created
+            assert len(set(returned_list_of_files).intersection(files_created)) == len(files_created)
 
     def test_flattened_download_datafile_returns_one_path(self):
         download_file = MagicMock()
@@ -570,7 +576,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 patch('dli.client.s3.os.makedirs') as makedirs_mock:
             sample_data = os.path.join(
                 os.path.dirname(__file__),
-                'resources/stocks'
+                '../../resources/stocks'
             )
 
             datafile = self.client.register_s3_datafile(
@@ -580,7 +586,7 @@ class RegisterDatafileTestCase(SdkIntegrationTestCase):
                 "prefix",
                 '2000-01-01'
             )
-            
+
 
             returned_list_of_files = self.client.download_datafile(
                 datafile.datafile_id, '/var/abc/', flatten=True)
