@@ -1,7 +1,7 @@
 import pytest
 import io
 import uuid
-
+import warnings
 from dli.client import builders
 from dli.client.exceptions import (
     CatalogueEntityNotFoundException, InvalidPayloadException,
@@ -11,6 +11,10 @@ from tests.common import SdkIntegrationTestCase
 @pytest.mark.integration
 class DatasetTestCase(SdkIntegrationTestCase):
 
+    @pytest.fixture(autouse=True)
+    def capsys(self, capsys):
+        self.capsys = capsys
+
     def setUp(self):
         super().setUp()
 
@@ -296,7 +300,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
             dataset.dataset_id,
             location_builder=builder,
             description="new desc",
-            content_type="content type",
+            content_type="Structured",
             keywords=["test", "2"],
             load_type="Full Load"
         )
@@ -305,7 +309,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
         self.assertEqual(updated.package_id, dataset.package_id)
         self.assertEqual(updated.name, dataset.name)
         self.assertEqual(updated.description, "new desc")
-        self.assertEqual(updated.content_type, "content type")
+        self.assertEqual(updated.content_type, "Structured")
         self.assertEqual(updated.keywords, ["test", "2"])
         self.assertEqual(updated.location.type, "Other")
         self.assertEqual(updated.load_type, "Full Load")
@@ -315,7 +319,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
             package_id=self.package_id,
             name="dataset_with_load_type",
             description="a testing dataset",
-            content_type="Pricing",
+            content_type="Structured",
             data_format="CSV",
             publishing_frequency="Daily",
             taxonomy=[],
@@ -342,7 +346,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
             package_id="unknown",
             name="test",
             description="a testing dataset",
-            content_type="Pricing",
+            content_type="Structured",
             data_format="CSV",
             publishing_frequency="Daily",
             taxonomy=[],
@@ -353,6 +357,45 @@ class DatasetTestCase(SdkIntegrationTestCase):
         with self.assertRaises(CatalogueEntityNotFoundException):
             self.client.register_dataset(builder)
 
+    def test_indirect_get_dataset_deprecation(self):
+        builder = self.builder.with_external_storage(
+            location="jdbc://connectionstring:1232/my-db"
+        )
+        expected = self.client.register_dataset(builder)
+
+        def indirect_call():
+            return self.client.get_dataset(expected.dataset_id)
+
+        with warnings.catch_warnings(record=True) as ws:
+            warnings.simplefilter("always")
+            actual = indirect_call()
+            found_deprecation = False
+            for w in ws:
+                if str(w.message).startswith("This method is deprecated and is scheduled for removal"):
+                    found_deprecation = True
+
+            assert found_deprecation is False
+
+    def test_direct_get_dataset_deprecation(self):
+        builder = self.builder.with_external_storage(
+            location="jdbc://connectionstring:1232/my-db"
+        )
+        expected = self.client.register_dataset(builder)
+
+        with warnings.catch_warnings(record=True) as ws:
+            # Cause all warnings to always be triggered.
+            warnings.simplefilter("always")
+            actual = self.client.get_dataset(expected.dataset_id)
+
+            found_deprecation = False
+            for w in ws:
+                if str(w.message).startswith("This method is deprecated and is scheduled for removal"):
+                    found_deprecation = True
+
+            assert found_deprecation is True
+
+
+
 
 @pytest.mark.integration
 class DatasetDatafilesTestCase(SdkIntegrationTestCase):
