@@ -1,8 +1,12 @@
 import operator
+import os
 import re
 from collections import OrderedDict
 
+import boto3
 import pytest
+from freezegun import freeze_time
+from moto import mock_s3
 
 from dli.client.dli_client import DliClient
 from datetime import datetime
@@ -14,6 +18,7 @@ class TestClientMock(DliClient):
     def __init__(self, args, kwargs):
         self._session = MagicMock()
         self._session.auth_key = 'abc'
+        self.strict = False
         self._session.token_expires_on = datetime(2100, 1, 1)
         self._environment = MagicMock()
         self._environment.consumption = ''
@@ -142,7 +147,7 @@ def package_request_index_accessible_content_v2():
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def package_request_index_unaccessible_content_v2():
     return {
         'type': 'package',
@@ -184,6 +189,7 @@ def package_request_index_v2(package_request_index_accessible_content_v2,
         }
     }
 
+
 @pytest.fixture
 def dataset_request_index_accessible_content_v2():
     return {
@@ -210,6 +216,8 @@ def dataset_request_index_accessible_content_v2():
          },
          'id': '5b01376e-975d-11e9-8832-7e5ef76d533f'
     }
+
+
 @pytest.fixture
 def dataset_request_index_unaccessible_content_v2():
     return {
@@ -237,6 +245,7 @@ def dataset_request_index_unaccessible_content_v2():
          'id': '5b01376e-975d-11e9-8832-7e5ef76d533f'
     }
 
+
 @pytest.fixture
 def dataset_request_index_v2(dataset_request_index_accessible_content_v2,
                              dataset_request_index_unaccessible_content_v2):
@@ -298,6 +307,28 @@ def dataset_request_v2():
       }
 
 
+@pytest.fixture
+def visible_orgs_v2():
+    return {
+        'data': [{
+            'attributes': {
+                'external_company_id': '47cbc80a-d9ad-4aeb-9263-10646b6c9a8e',
+                'created_by': 'tim@ihsmarkit.com',
+                'description': None,
+                'is_visible': True,
+                'name': 'testorg',
+                'short_code': 'karolinatestorgR9QZ',
+                'created_on': '2020-06-02T09:06:03.473793+00:00',
+                'updated_by': 'Karolina.Olszewska@ihsmarkit.com',
+                'updated_on': '2020-06-02T09:06:03.473793+00:00',
+                'domains': [{'domain_name': 'karolina.test'}]
+            },
+           'id': 'e3546799-db0f-48c4-81a3-b1b62669f05a'
+        }]
+    }
+
+
+
 @pytest.fixture
 def instance_request_v1():
     return {
@@ -349,4 +380,126 @@ def fields_request_v2():
             'id': '2d113c3a-be1a-4c70-b87a-8e569dee8dd0'
         },
         'meta': {'total_count': 3}
+    }
+
+@pytest.fixture
+def unstructured_dataset_request_v2():
+    return {
+            'data': {
+                'type': 'dataset',
+                'attributes': {
+                     'package_id': '59e6a698-975d-11e9-84cc-7e5ef76d533f',
+                     'updated_by': 'update@ihsmarkit.com',
+                     'keywords': [],
+                     'location': {},
+                     'content_type': 'Unstructured',
+                     'has_access': False,
+                     'first_datafile_at': '2019-05-06',
+                     'short_code': 'TestDataset',
+                     'absolute_taxonomy': 'Data-Test',
+                     'publishing_frequency': 'Monthly',
+                     'name': 'Test DataSet',
+                     'last_datafile_at': '2020-01-01',
+                     'data_format': 'PARQUET',
+                     'created_at': '2019-06-25',
+                     'description': 'description',
+                     'organisation_name': 'IHS Markit',
+                     'created_by': 'creator@ihsmarkit.com',
+                     'taxonomy': []
+                 },
+             'id': '5b01376e-975d-11e9-8832-7e5ef76d533f'
+        }
+      }
+
+
+@pytest.fixture
+def unstructured_dataset_request_index_accessible_content_v2():
+    return {
+        'type': 'dataset',
+         'attributes': {
+             'package_id': '59e6a698-975d-11e9-84cc-7e5ef76d533f',
+             'updated_by': 'update@ihsmarkit.com',
+             'keywords': [],
+             'location': {},
+             'content_type': 'Unstructured',
+             'has_access': True,
+             'first_datafile_at': '2019-05-06',
+             'short_code': 'TestDataset',
+             'absolute_taxonomy': 'Data-Test',
+             'publishing_frequency': 'Monthly',
+             'name': 'Test DataSet',
+             'last_datafile_at': '2020-01-01',
+             'data_format': 'PARQUET',
+             'created_at': '2019-06-25',
+             'description': 'description',
+             'organisation_name': 'IHS Markit',
+             'created_by': 'creator@ihsmarkit.com',
+             'taxonomy': []
+         },
+         'id': '5b01376e-975d-11e9-8832-7e5ef76d533f'
+    }
+
+
+@pytest.fixture
+def aws_s3():
+    """Set up Mock S3"""
+    with mock_s3() as s3:
+        yield s3
+
+@pytest.fixture
+def object_summaries_s3(aws_s3, request):
+    path = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "..",
+        'resources', 's3_listings'))
+
+    with freeze_time('2020-01-01T00:00:00Z'):
+        s3_resource = boto3.resource('s3')
+        bucket = s3_resource.create_bucket(Bucket='bucket')
+
+        for root, dirs, files in os.walk(path):
+            for file in files:
+                with open(os.path.join(root, file), 'rb') as f:
+                    file_data = f.read()
+
+                s3_resource.Object('bucket',
+                   f'abc/{root.replace(path + "/", "")}/{file}').put(
+                    Body=file_data
+                )
+
+    yield [f for f in bucket.objects.all()]
+
+@pytest.fixture
+def unstructured_object_summaries_s3(aws_s3, request):
+    path = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "..",
+        'resources', 's3_unstructured_listings'))
+
+    with freeze_time('2020-01-01T00:00:00Z'):
+        s3_resource = boto3.resource('s3')
+        bucket = s3_resource.create_bucket(Bucket='bucket')
+
+        for root, dirs, files in os.walk(path):
+            for file in files:
+                with open(os.path.join(root, file), 'rb') as f:
+                    file_data = f.read()
+
+                s3_resource.Object('bucket',
+                   f'abc/{root.replace(path + "/", "")}/{file}').put(
+                    Body=file_data
+                )
+
+    yield [f for f in bucket.objects.all()]
+
+
+@pytest.fixture
+def unstructured_dataset_request_index_v2(unstructured_dataset_request_index_accessible_content_v2,
+                                          dataset_request_index_unaccessible_content_v2):
+    return {
+        'data': [
+            unstructured_dataset_request_index_accessible_content_v2,
+            dataset_request_index_unaccessible_content_v2
+        ],
+        'meta': {
+            'total_count': 2,
+            'page': 1,
+            'total_pages': 1
+        }
     }
\ No newline at end of file
