@@ -248,7 +248,9 @@ def test_api_key_deprecation_warning(recwarn, monkeypatch):
     assert(dl.secret_key is not None and dl.access_id is None)
 
 
-def test_credentials_and_api_key(mock_create_env_user, monkeypatch):
+def test_credentials_and_api_key(
+    clear_keyring, mock_create_env_user, monkeypatch
+):
     # test flow when u/p set and api key set
     # api key should override
     monkeypatch.setattr(DliClient, '_new_session',  MagicMock())
@@ -263,7 +265,9 @@ def test_api_session(mock_create_env_user, mock_session):
     assert sesh._get_auth_key.call_count == 1
 
 
-def test_credentials_and_no_api_key(mock_create_env_user, monkeypatch, caplog):
+def test_credentials_and_no_api_key(
+        clear_keyring, mock_create_env_user, monkeypatch, caplog
+):
     # test flow when no credentials and api key set
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMock)
     dl = _start_session()
@@ -292,7 +296,7 @@ def test_api_key_auth(mock_del_env_user, monkeypatch):
     assert(dl and dl._session.auth_key is not None)
 
 
-def test_credentials_auth(mock_create_env_user, monkeypatch):
+def test_credentials_auth(clear_keyring, mock_create_env_user, monkeypatch):
     # test new auth process (_get_SAM_auth_key())
     sam_response = {
         "access_token": valid_token,
@@ -513,7 +517,7 @@ def test_set_JWT_keyring_web_auth_key(monkeypatch):
 
 
 @pytest.mark.xfail
-@pytest.mark.skipif(os.environ.get('CI_PYPI_USER') is not None,
+@pytest.mark.skipif(True or os.environ.get('CI_PYPI_USER') is not None,
                     reason="Not runnable on gitlab - 8080 closed")
 @pytest.mark.integration
 def test_web_flow(clear_keyring, mock_del_env_user, monkeypatch):
@@ -547,7 +551,7 @@ def test_credentials_on_catalogue(clear_keyring, real_client):
     ) is not None)
 
 @pytest.mark.xfail
-@pytest.mark.skipif(os.environ.get('CI_PYPI_USER') is not None,
+@pytest.mark.skipif(True or os.environ.get('CI_PYPI_USER') is not None,
                     reason="Not runnable on gitlab - 8080 closed")
 @pytest.mark.integration
 @pytest.mark.parametrize('real_client', [('QA', "Credentials")],
